const char * dbus_menu_clean_xml = 
"<?xml version=\"1.0\"?>\n"
"<node name=\"/\">\n"
"    \n"
"	<interface name=\"com.canonical.dbusmenu\">\n"
"		\n"
"\n"
"\n"
"		<property name=\"Version\" type=\"u\" access=\"read\">\n"
"			\n"
"		</property>\n"
"\n"
"		<property name=\"TextDirection\" type=\"s\" access=\"read\">\n"
"			\n"
"		</property>\n"
"\n"
"		<property name=\"Status\" type=\"s\" access=\"read\">\n"
"			\n"
"		</property>\n"
"\n"
"		<property name=\"IconThemePath\" type=\"as\" access=\"read\">\n"
"			\n"
"		</property>\n"
"\n"
"\n"
"\n"
"		<method name=\"GetLayout\">\n"
"			\n"
"			<arg type=\"i\" name=\"parentId\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"i\" name=\"recursionDepth\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"as\" name=\"propertyNames\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"u\" name=\"revision\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"(ia{sv}av)\" name=\"layout\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"		</method>\n"
"\n"
"		<method name=\"GetGroupProperties\">\n"
"			\n"
"			<arg type=\"ai\" name=\"ids\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"as\" name=\"propertyNames\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"a(ia{sv})\" name=\"properties\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"		</method>\n"
"\n"
"		<method name=\"GetProperty\">\n"
"			\n"
"			<arg type=\"i\" name=\"id\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"s\" name=\"name\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"v\" name=\"value\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"		</method>\n"
"\n"
"		<method name=\"Event\">\n"
"			\n"
"			<arg type=\"i\" name=\"id\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"s\" name=\"eventId\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"v\" name=\"data\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"u\" name=\"timestamp\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"		</method>\n"
"\n"
"		<method name=\"EventGroup\">\n"
"			\n"
"			<arg type=\"a(isvu)\" name=\"events\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"ai\" name=\"idErrors\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"		</method>\n"
"\n"
"		<method name=\"AboutToShow\">\n"
"			\n"
"			<arg type=\"i\" name=\"id\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"b\" name=\"needUpdate\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"		</method>\n"
"\n"
"		<method name=\"AboutToShowGroup\">\n"
"			\n"
"			<arg type=\"ai\" name=\"ids\" direction=\"in\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"ai\" name=\"updatesNeeded\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"ai\" name=\"idErrors\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"		</method>\n"
"\n"
"\n"
"		<signal name=\"ItemsPropertiesUpdated\">\n"
"			\n"
"			<arg type=\"a(ia{sv})\" name=\"updatedProps\" direction=\"out\"/>\n"
"			<arg type=\"a(ias)\" name=\"removedProps\" direction=\"out\"/>\n"
"		</signal>\n"
"		<signal name=\"LayoutUpdated\">\n"
"			\n"
"			<arg type=\"u\" name=\"revision\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"i\" name=\"parent\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"		</signal>\n"
"		<signal name=\"ItemActivationRequested\">\n"
"			\n"
"			<arg type=\"i\" name=\"id\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"			<arg type=\"u\" name=\"timestamp\" direction=\"out\">\n"
"				\n"
"			</arg>\n"
"		</signal>\n"
"\n"
"\n"
"\n"
"	</interface>\n"
"</node>\n"
;
